Re: [PATCH] fetch: avoid quadratic loop checking for updated submodules
- From
Jens Lehmann <jens.lehmann@web.de>
- Date
- Sep 13, 2011, 19:34 UTC
- Message-ID
- <4E6FB05C.6010202@web.de>
- In-Reply-To
- <7vwrdd5x61.fsf@alter.siamese.dyndns.org>
Am 12.09.2011 22:21, schrieb Junio C Hamano:
Show 5 quoted lines
> Jeff King <peff@peff.net> writes: > >> Instead, this patch structures the code like this: > > Yup, I agree that's the right way to do the other half of the issue.
Ack from me too! I tested it on the repo with 3k refs and the time went down from 142s to 1s (when applied to 3793ac56b4, as later versions of master contain my other half which would skip Peff's code).
On current master including my other half this takes 0.90s, while running with Peff's code on top of 3793ac56b4 it takes .96s. That is 6 hundreds of a second (7%) extra for not having to worry if one must run "git fetch --recurse-submodules" or not.